# $Id: /mirror/coderepos/lang/perl/Google-Chart/trunk/lib/Google/Chart/Type/Line.pm 72334 2008-09-06T13:00:51.986261Z daisuke  $

package Google::Chart::Type::Line;
use Moose;
use constant parameter_value => 'lc';

with 'Google::Chart::Type::Simple';

no Moose;

1;

__END__

=head1 NAME

Google::Chart::Type::Line - Google::Chart Line Type

=cut